# Welcome to PyTimings's documentation!

```{toctree}
:maxdepth: 2
:caption: "Contents:"

readme
changelog
installation
usage
contributing
authors
autoapi/index

```

# Indices and tables

* {ref}`genindex`
* {ref}`modindex`
* {ref}`search`
